@@ -16,7 +16,9 @@ from flask import Response
 
 from jupyterhub.services.auth import HubAuth
 
-_PROFILES = SingleuserProfiles(verify_ssl=False)
+custom_notebook_namespace = os.environ['NOTEBOOK_NAMESPACE']
+
+_PROFILES = SingleuserProfiles(notebook_namespace=custom_notebook_namespace, verify_ssl=False)
 _PROFILES.load_profiles()
 
 _LOGGER = logging.getLogger(__name__)
